#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 test-framework-leancheck
version:              0.0.4
visibility:           public
id:                   test-framework-leancheck-0.0.4-dPbxXMPRsAViHYIu0mFy
key:                  test-framework-leancheck-0.0.4-dPbxXMPRsAViHYIu0mFy
license:              BSD-3-Clause
maintainer:           Rudy Matela <rudy@matela.com.br>
author:               Rudy Matela <rudy@matela.com.br>
homepage:
    https://github.com/rudymatela/test-framework-leancheck#readme

synopsis:             LeanCheck support for test-framework.
description:
    LeanCheck support for test-framework.

    This package can be used to incorporate LeanCheck tests
    into test-framework test suites.

    Please see the Haddock documentation and README for more details.

category:             Testing
abi:                  12a7e5d3024ab60c4fdfe6659e10e511
exposed:              True
exposed-modules:      Test.Framework.Providers.LeanCheck
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/test-framework-leancheck-0.0.4

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-test-framework-leancheck
hs-libraries:         HStest-framework-leancheck-0.0.4-dPbxXMPRsAViHYIu0mFy
depends:
    base-4.18.2.1 leancheck-1.0.2-3Q5gjzA8lue3H9rlyJUOcN
    test-framework-0.8.2.3-HtqlCb8d1eBHA7kBalFrJK

haddock-interfaces:
    /usr/share/doc/haskell-test-framework-leancheck/html/test-framework-leancheck.haddock

haddock-html:         /usr/share/doc/haskell-test-framework-leancheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

